package net.sergeych.synctools

/**
 * Platform-independent interface to thread wait/notify. Does nothing in JS/browser,
 * and uses appropriate mechanics on other platforms.
 */
@Suppress("EXPECT_ACTUAL_CLASSIFIERS_ARE_IN_BETA_WARNING")
expect class WaitHandle() {

    /**
     * Wait for [wakeUp] as long as [milliseconds] milliseconds, or forever.
     * Notice it returns immediately on the single-theaded platforms like JS.
     * @param milliseconds to wait, use 0 to wait indefinitely
     * @return true if [wakeUp] was called before the timeout, false on timeout.
     */
    fun await(milliseconds: Long=0): Boolean

    /**
     * Awake all [await]'ing threads. Does nothing in the single-threaded JS
     * environment
     */
    fun wakeUp()
}